﻿
// Dundas BI Sample Code
// 2018 Dundas Data Visualization Inc.


using System;
using System.Collections.Generic;
using System.IO;
using System.IO.Compression;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace SlackSample
{
	public static class StreamExtensions
	{
        #region Public Methods

        /// <summary>
        /// Converts a Stream to a byte array.
        /// </summary>
        /// <param name="stream">The stream.</param>
        /// <returns>A byte array.</returns>
        public static byte[] ToByteArray(this System.IO.Stream stream)
		{
			using (stream)
			{
				using (System.IO.MemoryStream memStream = new System.IO.MemoryStream())
				{
					stream.CopyTo(memStream);
					return memStream.ToArray();
				}
			}
		}

        /// <summary>
        /// Converts a files bytes to zip bytes with a file inside.
        /// </summary>
        /// <param name="stream">The stream.</param>
        /// <param name="fileName">Name of the file.</param>
        /// <returns>Zip bytes with a file inside</returns>
        public static byte[] ToZippedBytes(this System.IO.Stream stream, string fileName)
        {
            using (var outputStream = new MemoryStream())
            {
                using (ZipArchive zipArchive = 
                    new ZipArchive(outputStream, ZipArchiveMode.Create, true))
                {
                    var fileInArchive = zipArchive.CreateEntry(fileName, CompressionLevel.Optimal);
                    using (var entryStream = fileInArchive.Open())
                    using (var fileToCompressStream = new MemoryStream(stream.ToByteArray()))
                    {
                        fileToCompressStream.CopyTo(entryStream);
                    }

                }
                return outputStream.ToArray();
            }
        }

		#endregion Public Methods
	}
}